@@ -1,4 +1,5 @@
 import ctypes
+from re import I
 import tkinter as tk
 import tkinter.ttk as ttk
 from ctypes import POINTER, Structure, windll
@@ -362,6 +363,15 @@ class DevManage(object):
         self.rgbBlack = 0x00000000
         self.rgbWhite = 0x00FFFFFF
 
+    def get_rgb(self, red: int, green: int, blue: int):
+        from ctypes.wintypes import RGB
+        return RGB(red, green, blue)
+
+    def get_hex(self, hex: int):
+        from PIL import ImageColor
+        color = ImageColor.getcolor(hex, "RGB")
+        return self.get_rgb(color[0], color[1], color[2])
+
     def high_dpi(self):
         try:
             self.Shcore.SetProcessDpiAwareness(2)
@@ -1528,7 +1538,7 @@ class DevWindow(tk.Tk):
         """
         居中窗口
         """
-        self.after(1, lambda evt=None: window_centre(self))
+        DevManage(self).set_window_pos_center()
 
     centre = wm_centre
 
